//=========================================================================\\
//=========================================================================\\
//
// app.js is the Entry point into the test suite.
// The basic flow is to create a simple window, a table view data object,
// a table view, and add that table view to the window, then open the window.
// We use a property called "file" to determine which test case to execute.
// The convention is to use the commonjs practice of require that file then
// executing it's runTestCase function loaded from the exports variable.
//
//=========================================================================\\
//=========================================================================\\

// this sets the background color of the master UIView (when there are no windows/tab groups on it)
Titanium.UI.setBackgroundColor('#000');

var tabGroup = Titanium.UI.createTabGroup();
//
// create base UI tab and root window
//
var win = Titanium.UI.createWindow({  
    title:'Performance Test Suite',
    backgroundColor:'#fff'
});

var tab1 = Titanium.UI.createTab({  
    title:'Test Cases',
    window:win
});

// Main table view data object that holds the information about
// each given test case.
// 
// file: the property that holds the js file for the given test case
var tvData = [
	{title:'basic object creation', hasChild:true, hasDetail: true, file: './testcases/objectcreation/basicobjectcreation'},
	{title:'object creation with scaling', hasChild:true, hasDetail: true, file: './testcases/objectcreation/objectcreationwithscaling'},
	{title:'heavyweight window creation', hasChild:true, hasDetail: true, file: './testcases/windowinstantiation/heavyweightwindowcreation'},
	{title:'lightweight window creation', hasChild:true, hasDetail: true, file: './testcases/windowinstantiation/lightweightwindowcreation'},
	{title:'basic vertical panning', hasChild:true, hasDetail: true, file: './testcases/panning/verticalPanning'},
	{title:'basic horizontal panning', hasChild:true, hasDetail: true, file: './testcases/panning/horizontalPanning'},
	{title:'basic scrollableview scrolling', hasChild:true, hasDetail: true, file: './testcases/scrolling/scrollableview'},
	{title:'basic tableview scrolling', hasChild:true, hasDetail: true, file: './testcases/scrolling/tableview'},
	{title:'button gestures', hasChild:true, hasDetail: true, file: './testcases/gestureresponse/buttonGestures'},
	{title:'image from URL', hasChild:true, hasDetail: true, file: './testcases/imagerendering/imagefromurl'},
	{title:'image from local', hasChild:true, hasDetail: true, file: './testcases/imagerendering/imagefromlocal'},
	{title:'image from blob', hasChild:true, hasDetail: true, file: './testcases/imagerendering/imagefromblob'}
];

var tableView = Titanium.UI.createTableView({
	data:tvData
});

// create table view event listener
tableView.addEventListener('click', function(e)
{
	if (e.rowData.file)
	{
		// We require in the test case then execute it's runTestCase function.
		var testCase = require(e.rowData.file);
		
		var childWin = Titanium.UI.createWindow({
			title: e.rowData.title,
			backgroundColor: '#fff'
		});
		
		if(testCase.runManual === undefined) {
			var result = testCase.runTestCase();
			var resultLabel = Ti.UI.createLabel({
				text: result,
				font: { fontSize: 48 },
			});
			
			childWin.add(resultLabel);
			tab1.open(childWin,{animated:true});	
		}
		else {
			testCase.runManual(tab1, childWin);
		}
		
	}
});

// add table view to the window
win.add(tableView);
tabGroup.addTab(tab1);
tabGroup.open(); 
